################# Function for generating cross validated predictions using MLR ##################
#
# Created by Pablo Mendoza, March 8 2015
#
##################################################################################################
#
# This function generates cross-validated predictions using multiple linear regression (MLR).
# The best model is selected based on the minimum RMSE.
#
# Inputs required:
#
# Xpredictor  :  Matrix containing predictors to be used for training ( [Nsyears x (Ngroups-1)] x Npred )
# Xpredict    :  Matrix to be used for predicting ( Nsyears x Npred )
# Ypredictand :  Column vector containing the predictors to be used ( [Nsyears x (Ngroups-1)] x1 )
# combinations:  Logical (TRUE/FALSE) matrix containing all predictor combinations to be considered
# Nsyears     :  Number of years left out for cross-validation
#
##################################################################################################


PredictMLRLasso <- function(Xpredictor,Xpredict,Ypredictand,combinations,Nsyears) {
  
  # Load required libraries (Bayesian Lasso!)
  library(monomvn)
  
  #cvlasso    = cv.glmnet(Xpredictor, Ypredictand, nfolds = 8, alpha = 1)
  #bestmodel  = glmnet(Xpredictor,Ypredictand,lambda=cvlasso$lambda.min, alpha = 1)
  #zp         = predict(bestmodel, newx = Xpredict, type = "response", se.fit=TRUE )
  
  
  bestmodel   = blasso(Xpredictor,Ypredictand,T=Nens)
  Yreturn     = bestmodel$mu + bestmodel$beta %*% t(Xpredict)
  #beta        = colMeans(bestmodel$beta)
  #beta        = colMeans(bestmodel$beta) * (colMeans(bestmodel$beta != 0)  > 0.5)
  #post_pred_y = with(bestmodel, Xpredictor %*% t(beta))
  #y_pred <- rowMeans(post_pred_y)
  
  return(Yreturn)
  
  
}
