############### Function for making scatter plots with predictions vs. observations ##############
#
# Created by Pablo Mendoza, March 18 2015
#
##################################################################################################
#
# Inputs required:
#
# Forecasts    :  Time series with ensemble forecasts (Ntime x Nens)
# Observations :  Time series with observations (Ntime x 1)
# xlabel       :  Label for x axis
# ylabel       :  Label for y axis
#
##################################################################################################

ScatterPlotsCorBias <- function(Forecasts,Observations,xlabel,ylabel) {
  
  # Make plot
  plot(Observations,Forecasts,xlim=range(Observations,Forecasts),ylim=(xlim=range(Observations,Forecasts)),
       xlab=xlabel,ylab=ylabel,pch=1,las=1,cex.lab=1.3, cex.axis=1.3)
  lines(range(Observations,Forecasts)+c(-10,10),range(Observations,Forecasts)+c(-10,10))
  
  # Add correlation and percent bias
  correlation = cor(Observations,Forecasts)
  pbias       = (sum(Forecasts - Observations) )/sum(Observations)*100
  rmse        = sqrt(sum((Observations - Forecasts)^2)/length(Observations))
  Title       = paste('% Bias = ',toString(round(pbias,digits=2)),sep='')
  subtitle    = paste('r=',round(correlation,digits=2),'; RMSE=',round(rmse,digits=3),sep='')
  mtext(Title,side=3,line=2,cex=1.0)
  mtext(subtitle,side=3,line=1,cex=1.0)
  Yreturn     = list(correlation=correlation,pbias=pbias,rmse=rmse)
  return(Yreturn)
  
}